.. highlight:: shell

============
Installation
============


Stable release
--------------

There is no stable release yet. See next section on installing from sources.


From sources
------------

Requirements
============

- Python (>= 3.5 recommended)
- Python packages: numpy, scipy, matplotlib, urllib3

Installation
============

The sources for spharpy can be downloaded from the `git repository`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://git.rwth-aachen.de/mbe/spharpy

or download the code from the `GitLab pages`_.

You can install it with:

.. code-block:: console

    $ python setup.py install

.. _GitLab pages: https://git.rwth-aachen.de/mbe/spharpy
.. _git repository: https://git.rwth-aachen.de/mbe/spharpy
